#!/bin/sh
#
# vim: set expandtab shiftwidth=2 softtabstop=2:
# 
# WARNING
# This command rewrites archives.  It has not been thoroughly tested,
# and it could cause IRREVERSIBLE damage to your archive.  Use at your
# own risk.
#
# =fix-archive.sh - remove temporary files from stored patches
#
# This fixes the following issue:
# http://lists.fifthvision.net/pipermail/arch-users/2002-December/001069.html
#
################################################################
# Copyright (C) 2001, 2002 Tom Lord, Alexander Deruwe
# Copyright (C) 2002 Walter Landry and 
#                    the Regents of the University of California
#
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
#

set -e


################################################################
# Ordinary arguments
#

if test $# -ne 0 ; then
  archive_root="$1"
else
  archive_root="`pwd`"
fi


################################################################
# Regular expressions
#

base_re="([a-zA-Z]([a-zA-Z0-9]*(-[a-zA-Z0-9]+)?)*)"
category_re="^($base_re)$"
branch_re="^($base_re)(--$base_re)?$"
version_re="^($base_re)(--$base_re)?((--[0-9]+\\.[0-9]+))$"
patch_re="^(base-0|patch-[0-9]+|version-0|versionfix-[0-9]+)$"


################################################################
# Do it
#

cd "$archive_root"
for cat in `ls -1 | grep -E "$category_re"` ; do
  cd "$cat"
  for branch in `ls -1 | grep -E "$branch_re"` ; do
    cd "$branch"
    for version in `ls -1 | grep -E "$version_re"` ; do
      cd "$version"
      for patch in `ls -1 | grep -E "$patch_re" | sort` ; do
        cd "$patch"
        printf "`pwd`\\n"

        # If revision is a continuation revision, the patch tarball name is
        # standard, otherwise it indicates that it is full source (i.e. it
        # does not have the problem we are looking for).
        if test $patch = "base-0" && test -e "$version--$patch.src.tar.gz" ; then
          cd ..
          continue
        else
          patchdir="$version--$patch.patches"
          tarball="$patchdir.tar.gz"
        fi

        printf "Unpacking $tarball...\\n"
        tar zxvf "$tarball" > /dev/null

        printf "Removing temporary files in $patchdir...\\n"
        cd "$patchdir"
        rm -f ,,*
        cd ..

        printf "Recreating $tarball...\\n"
        tar zcvf "$tarball" "$patchdir" > /dev/null

        printf "Removing patch directory: $patchdir\\n"
        rm -rf "$patchdir"
        cd ..

        printf "\\n"
      done
      cd ..
    done
    cd ..
  done
  cd ..
done
