# 
# cat-archive-log.sh - spew an archive log file
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "print the contents of an archive log entry\\n"
                printf "usage: cat-archive-log [options] [archive/]revision \\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "  --headers                   show only log headers\\n"
                printf "\\n"
                printf "Print the contents of the log entry for REVISION.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
headers_only=
debug_opt=

while test $# -ne 0 ; do

  case "$1" in 

    --debug)                shift
                            debug_opt=--debug
                        printf "\n" 1>&2
                        printf "cat-archive-log: DEBUGGING ACTIVATED\n" 1>&2
                        printf "\n" 1>&2
                        set -x
                        ;;

    --headers)                shift
                            headers_only=--headers
                        ;;

    --)                        shift
                            break
                        ;;
                        
    -*)                 printf "cat-archive-log: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# ordinary arguments
# 

if test $# -ne 1 ; then
  printf "usage: cat-archive-log [options] [archive/]revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

archive_revision="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

archive="`arx parse-package-name --arch \"$archive_revision\"`"
revision="`arx parse-package-name --non-arch \"$archive_revision\"`"

arx valid-archive-name -e cat-archive-log -- "$archive"
arx valid-package-name -e cat-archive-log --patch-level -- "$revision"

category=`arx parse-package-name --basename $revision`
branch=`arx parse-package-name $revision`
vsn=`arx parse-package-name --vsn $revision`
lvl=`arx parse-package-name --lvl $revision`

log_file=$category/$branch/$branch--$vsn/$lvl/log



################################################################
# Ensure that We Have an Archive Connection 
# 

if test "$WITHARCHIVE" != "$archive" ; then

  exec arx with-archive -A "$archive" \
      arx cat-archive-log $debug_opt $headers_only "$archive/$revision" 
fi

################################################################
# Print the Log Entry
# 

wftp-home

if test -z "$headers_only" ; then
  wftp-get $log_file
else
  wftp-get $log_file | sed -e "/^\$/,\$d"
fi
