# 
# delete-branch.sh - delete a branch within an archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "IRREVOCABLY delete branch within an archive, along with all\\n"
		printf "associated versions, and revisions.\\n"
                printf "usage: delete-branch [options] [archive/]branch\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Delete BRANCH as a branch in the indicated archive.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
readme=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                        printf "delete-branch: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
    printf "usage: delete-branch [options] branch\\n" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
fi

branch="$1"

################################################################
# Sanity Check 
# 

arx valid-package-name -e delete-branch -- "$branch"
idstr="`arx my-id -e delete-branch`"

archive="`arx parse-package-name --arch \"$branch\"`"
category="`arx parse-package-name --basename \"$branch\"`"
branch="`arx parse-package-name --package \"$branch\"`"

################################################################
# Remove the branch
# 

status=0

if ! arx with-archive -A "$archive" arx arch-rmrf "$category/$branch" ; then
  printf "delete-branch: unable to delete branch\\n" 1>&2
  status=1
fi

exit "$status"
