# 
# copy-non-source-goodies.sh - copy non-source goodies between project tree
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "copy non-source goodies from one project tree to another\\n"
                printf "usage: copy-non-source-goodies [options] old-dir new-dir\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Copy non-source goodies and nested project trees from the directory\\n"
                printf "OLD-DIR to corresponding locations in NEW-DIR.\\n"
                printf "\\n"
                printf "When copying non-source goodies, this command won't create new source\\n"
                printf "directories in NEW-DIR.  If a non-source goodies file in OLD-DIR is in a\\n"
                printf "directory not found in NEW-DIR, that file is copied to a subdirectory\\n"
                printf "of NEW-DIR/++lost-non-source goodies.\\n"
                printf "\\n"
                printf "When copying nested project trees, the entire tree is copied except for junk.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                 printf "copy-non-source-goodies: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 2 ; then
  printf "usage: copy-non-source-goodies [options] old-dir new-dir\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

old_dir="$1"
shift

new_dir="$1"
shift

here="`pwd`"

cd "$old_dir"
old_dir="`pwd`"

cd "$here"
cd "$new_dir"
new_dir="`pwd`"


################################################################
# Copy Nested Project Trees
# 

cd "$old_dir"

arx inventory --trees \
| xargs -n 1 need-args "arx inventory --source --precious --backups --unrecognized --control --nested --files --" \
| awk '{print $2}' \
| copy-file-list -- - "$old_dir" "$new_dir"



################################################################
# Make Space for Lost Precious Files
# 

cd "$new_dir"

mkdir ,,lost-precious.$$
cd ,,lost-precious.$$
lost_dir="`pwd`"

cd "$old_dir"

arx inventory --precious \
| awk -v new_dir="$new_dir" \
      -v lost_dir="$lost_dir" \
      '{ print "arx copy-or-stash \"" $0 "\" \"" new_dir "\" \"" lost_dir "\""; }' \
| $ARCH_SHELL -e 

arx inventory --unrecognized \
| awk -v new_dir="$new_dir" \
      -v lost_dir="$lost_dir" \
      '{ print "arx copy-or-stash \"" $0 "\" \"" new_dir "\" \"" lost_dir "\""; }' \
| $ARCH_SHELL -e 

arx inventory --backups \
| awk -v new_dir="$new_dir" \
      -v lost_dir="$lost_dir" \
      '{ print "arx copy-or-stash \"" $0 "\" \"" new_dir "\" \"" lost_dir "\""; }' \
| $ARCH_SHELL -e 

if ! rmdir "$lost_dir" 2> /dev/null ; then
  mv "$lost_dir" "++lost-precious.`date +%Y-%m-%d`.$$"
fi

