# 
# with-archive.sh - connect to a possibly remote archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e 
errname=with-archive

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "*+connect to a (possibly remote) archive\\n"
                printf "usage: with-archive [options] command [args...]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -A --archive archive          specify the archive name\\n"
                printf " -e --errname name             program name for error messages\\n"
                printf "\\n"
                printf "Connect to the default archive and execute COMMAND with ARGS.\\n"
                   printf "\\n"
                printf "If the archive is remote this involves logging in to the remote\\n"
                printf "FTP server.\\n"
                printf "\\n"
                printf "For information about how the archive to operate on is selected,\\n"
                printf "try \"arx my-default-archive --help\".\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -A|--archive)        shift
                            if test $# -eq 0 ; then
                          printf "with-archive: -A and --archive require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        archive="$1"
                        shift
                        ;;

    -e|--errname)        shift
                            if test $# -eq 0 ; then
                          printf "with-archive: -e and --errname require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        errname="$1"
                        shift
                        ;;

    -*)                        printf "with-archive: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -lt 1 ; then
    printf "usage: with-archive [options] command [args...]\\n" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
fi

################################################################
# Sanity Check and Process Defaults
# 

archive=`arx my-default-archive -e "$errname" -A "$archive"`

################################################################
# Find the Archive Location
# 

location="`arx whereis-archive $archive`"

################################################################
# Connect and execute the command
# 

if test "$WITHARCHIVE" = "$archive" ; then

  loc="`wftp-pwd`"
  wftp-home
  "$@"
  wftp-home
  wftp-cd "$loc"

else

  WITHARCHIVE="$archive"
  WITHARCHIVELOC="$location"

  export WITHARCHIVE
  export WITHARCHIVELOC

  with-ftp "$location" "$@"

fi

