# vim: set expandtab shiftwidth=2 softtabstop=2:
#
# my-browser.sh - the user's browser
#
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002 Alexander Deruwe
# Copyright (C) 2003 Walter Landry and the Regents
#                    of the University of California
# 
# See the file "COPYING" for further information about
# the copyright and warranty status of this work.
# 

set -e

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then
  for opt in "$@" ; do
    case $opt in
      --version|-V)
          exec arx --version
          ;;


      --help|-h)
          printf "print or change your default arch browser\\n"
          printf "usage: my-browser [options] browser-string\\n"
          printf "\\n"
          printf " -V --version                  print version info\\n"
          printf " -h --help                     display help\\n"
          printf "\\n"
          printf " -v --verbose                  print a reassuring message\\n"
          printf "\\n"
          printf "With no argument print your default arch browser.\\n"
          printf "\\n"
          printf "With an argument, record BROWSER-STRING as your browser\\n"
          printf "in ~/.arch-params/=browser\\n"
          printf "\\n"
          exit 0
          ;;

      *)
          ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 

verbose=0
type=

while test $# -ne 0 ; do
  case "$1" in 
    -v|--verbose)
        shift
        verbose=1
        ;;

    -*)
        printf "my-browser: unrecognized option (%s)\\n" "$1" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
        ;;

    *)
        break
        ;;
  esac
done



################################################################
# Ordinary Arguments
# 

case $# in 
  0)
      type=print
      ;;

  1)
      type=set
      browser="$1"

      # If the new browser is an empty string,
      # then just print the current one
      if test -z "$browser" ; then
        type=print
      else
        set +e
        browserpath=`which "$browser"`
        set -e
      fi
      ;;

  *)
      if test $# -gt 1 ; then
        printf "usage: my-browser [options] [id-string]\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      ;;
esac


################################################################
# Sanity Check
#

if test $type = "set" ; then
  if test -z "$browserpath" ; then
    printf "my-browser: invalid browser (%s)\\n" "$browser" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
  fi
fi


################################################################
# Do It
# 

browserfile="=browser"
archparamsdir=~/.arch-params

mkdir -p "$archparamsdir"
case $type in
  set)
      printf "%s\\n" "$browserpath" > "$archparamsdir/$browserfile"
      if test $verbose -ne 0 ; then
        printf "browser path set (%s)\\n" "$browserpath"
      fi
      ;;

  print)
      if test ! -e "$archparamsdir/$browserfile" ; then
        printf "my-browser: no browser path set!\\n" 1>&2
        printf "try --help\\n" 1>&2
        exit 1
      fi
      printf "%s\\n" "`cat $archparamsdir/$browserfile`"
      ;;
esac

exit 0
