;; Returns the completion for a version name

;; Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
;; of California

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(defun arx-complete-versions (partial-name predicate flag)
  "Returns the completion for a version name.  If the category name is
not complete or unique, it only looks up category names.  If the
branch name is not complete or unique, it looks up branch names.  If
the branch name is complete or unique, it looks up the version names."
  (arx-do-completion
   partial-name
   (let* ((name-list (arx-split-names partial-name))
	  (category (car name-list))
	  (branch (concat category "--" (nth 1 name-list)))
	  (version (concat branch "--" (nth 2 name-list))))
     ;; If version exists
     (if (= 3 (length name-list))
	 (arx-get-versions branch)
       (append
	;; Check for the case where the branch and category name is
	;; identical
	(let ((branch-category-list (arx-complete-branches category
							     predicate t)))
	  (if (= 1 (length branch-category-list))
	      (arx-get-versions (car branch-category-list))
	    (if (arx-complete-branches category predicate 'lambda)
		(arx-get-versions category))))
	;; If branch exists
	(if (= 2 (length name-list))
	    (append
	     (let ((branch-list (arx-complete-branches branch predicate t)))
	       ;; If there is only one or an exact match to branch, get
	       ;; the versions for that branch
	       (if (= 1 (length branch-list))
		   (arx-get-versions (car branch-list))
		 (if (arx-complete-branches branch predicate 'lambda)
		     (arx-get-versions branch))))
	     ;; In any case, return the branch completions, removing
	     ;; any that have had their versions completed.
	     (let ((branches (arx-get-branches category)))
	       (if (not (and (= 1 (length branches))
			     (string= partial-name branch)))
		   (remove partial-name branches))))
	  (let* ((category-list (arx-complete-categories category
							   predicate t))
		 (branch-list 
		  ;; If only one or exact match to category, get the branches
		  (if (= 1 (length category-list))
		      (arx-get-branches (car category-list))
		    (if (arx-complete-categories category predicate 'lambda)
			(arx-get-branches category)))))
	    (append
	    ;; If only one match to branch, get the versions.  We also
	    ;; don't have to worry about exact, non-unique matches
	    ;; because it was returned by arx-get-branches, not
	    ;; typed by the user.
	     (if (= 1 (length branch-list))
		 (arx-get-versions (car branch-list))
	       branch-list)
	     (if (not (and (= 1 (length category-list))
			   (string= partial-name category)))
		 (remove partial-name category-list))))))))
   predicate flag))
