;; Creates a log for committing a new version.  Also sets up a mode
;; for binding keys to make it easy to commit.

;; Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
;; of California

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(put 'arx-make-new-version-error
     'error-conditions
     '(error arx-error arx-make-new-version-error))

(put 'arx-make-new-version-error 'error-message "arx-make-new-version failed")


(defun arx-make-new-version (version)
  "Create a log file and set it up for editing"
  (interactive
   (list (completing-read "New version name: " 'arx-complete-versions)))
  (save-current-buffer
    (set-buffer (get-buffer-create "*arx*"))
    (erase-buffer))
  (if (= 0 (call-process "arx" nil "*arx*" t "make-log"
			 "--new-version" version))
      (progn
	(find-file (car (save-current-buffer
			  (set-buffer "*arx*")
			  (split-string (buffer-string) "\n"))))
	(arx-log-mode)
	(end-of-line)
	(let* ((name-list (arx-split-names version)))
	  (set (make-local-variable 'arx-new-version) version)
	  (set (make-local-variable 'arx-new-category) (car name-list))
	  (set (make-local-variable 'arx-new-branch)
	       (concat arx-new-category "--" (nth 1 name-list)))))
    (progn (display-buffer "*arx*" t)
	   (signal 'arx-make-new-version-error nil))))
